# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_pq.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/counters_pq.proto\x12\x0bNKikimr.NPQ\x1a\x1eydb/core/protos/counters.proto*\xb2\x11\n\x13\x45\x43umulativeCounters\x12,\n\x16\x43OUNTER_PQ_BAD_REQUEST\x10\x00\x1a\x10\x82\xd6\x1b\x0c\n\nBadRequest\x12/\n\x17\x43OUNTER_PQ_INITIALIZING\x10\x01\x1a\x12\x82\xd6\x1b\x0e\n\x0cInitializing\x12\x37\n\x1c\x43OUNTER_PQ_CREATE_SESSION_OK\x10\x02\x1a\x15\x82\xd6\x1b\x11\n\x0f\x43reateSessionOk\x12=\n\x1f\x43OUNTER_PQ_CREATE_SESSION_ERROR\x10\x03\x1a\x18\x82\xd6\x1b\x14\n\x12\x43reateSessionError\x12\x37\n\x1c\x43OUNTER_PQ_DELETE_SESSION_OK\x10\x04\x1a\x15\x82\xd6\x1b\x11\n\x0f\x44\x65leteSessionOk\x12=\n\x1f\x43OUNTER_PQ_DELETE_SESSION_ERROR\x10\x05\x1a\x18\x82\xd6\x1b\x14\n\x12\x44\x65leteSessionError\x12<\n\x1f\x43OUNTER_PQ_SET_CLIENT_OFFSET_OK\x10\x06\x1a\x17\x82\xd6\x1b\x13\n\x11SetClientOffsetOk\x12\x42\n\"COUNTER_PQ_SET_CLIENT_OFFSET_ERROR\x10\x07\x1a\x1a\x82\xd6\x1b\x16\n\x14SetClientOffsetError\x12<\n\x1f\x43OUNTER_PQ_GET_CLIENT_OFFSET_OK\x10\x08\x1a\x17\x82\xd6\x1b\x13\n\x11GetClientOffsetOk\x12\x42\n\"COUNTER_PQ_GET_CLIENT_OFFSET_ERROR\x10\t\x1a\x1a\x82\xd6\x1b\x16\n\x14GetClientOffsetError\x12$\n\x12\x43OUNTER_PQ_READ_OK\x10\n\x1a\x0c\x82\xd6\x1b\x08\n\x06ReadOk\x12*\n\x15\x43OUNTER_PQ_READ_ERROR\x10\x0b\x1a\x0f\x82\xd6\x1b\x0b\n\tReadError\x12>\n COUNTER_PQ_READ_ERROR_NO_SESSION\x10\x0c\x1a\x18\x82\xd6\x1b\x14\n\x12ReadErrorNoSession\x12\x42\n\"COUNTER_PQ_READ_ERROR_SMALL_OFFSET\x10\r\x1a\x1a\x82\xd6\x1b\x16\n\x14ReadErrorSmallOffset\x12>\n COUNTER_PQ_READ_ERROR_BIG_OFFSET\x10\x0e\x1a\x18\x82\xd6\x1b\x14\n\x12ReadErrorBigOffset\x12@\n!COUNTER_PQ_READ_ERROR_IN_PROGRESS\x10\x0f\x1a\x19\x82\xd6\x1b\x15\n\x13ReadErrorInProgress\x12\x36\n\x1c\x43OUNTER_PQ_READ_HEAD_ONLY_OK\x10\x10\x1a\x14\x82\xd6\x1b\x10\n\x0eReadHeadOnlyOk\x12=\n\x1f\x43OUNTER_PQ_READ_SUBSCRIPTION_OK\x10\x11\x1a\x18\x82\xd6\x1b\x14\n\x12ReadSubscriptionOk\x12\x43\n\"COUNTER_PQ_READ_SUBSCRIPTION_ERROR\x10\x12\x1a\x1b\x82\xd6\x1b\x17\n\x15ReadSubscriptionError\x12G\n$COUNTER_PQ_READ_SUBSCRIPTION_TIMEOUT\x10\x13\x1a\x1d\x82\xd6\x1b\x19\n\x17ReadSubscriptionTimeout\x12*\n\x15\x43OUNTER_PQ_READ_BYTES\x10\x14\x1a\x0f\x82\xd6\x1b\x0b\n\tBytesRead\x12\x31\n\x19\x43OUNTER_PQ_WRITE_BYTES_OK\x10\x15\x1a\x12\x82\xd6\x1b\x0e\n\x0c\x42ytesWriteOk\x12;\n\x1e\x43OUNTER_PQ_WRITE_BYTES_ALREADY\x10\x16\x1a\x17\x82\xd6\x1b\x13\n\x11\x42ytesWriteAlready\x12\x37\n\x1c\x43OUNTER_PQ_WRITE_BYTES_ERROR\x10\x17\x1a\x15\x82\xd6\x1b\x11\n\x0f\x42ytesWriteError\x12&\n\x13\x43OUNTER_PQ_WRITE_OK\x10\x18\x1a\r\x82\xd6\x1b\t\n\x07WriteOk\x12\x30\n\x18\x43OUNTER_PQ_WRITE_ALREADY\x10\x19\x1a\x12\x82\xd6\x1b\x0e\n\x0cWriteAlready\x12,\n\x16\x43OUNTER_PQ_WRITE_ERROR\x10\x1a\x1a\x10\x82\xd6\x1b\x0c\n\nWriteError\x12\x42\n\"COUNTER_PQ_WRITE_CYCLE_BYTES_TOTAL\x10\x1b\x1a\x1a\x82\xd6\x1b\x16\n\x14\x42ytesWriteCycleTotal\x12\x46\n$COUNTER_PQ_WRITE_TIMESTAMP_CACHE_HIT\x10\x1c\x1a\x1c\x82\xd6\x1b\x18\n\x16TimestampWriteCacheHit\x12H\n%COUNTER_PQ_WRITE_TIMESTAMP_CACHE_MISS\x10\x1d\x1a\x1d\x82\xd6\x1b\x19\n\x17TimestampWriteCacheMiss\x12\x43\n COUNTER_PQ_WRITE_TIMESTAMP_ERROR\x10\x1e\x1a\x1d\x82\xd6\x1b\x19\n\x17TimestampWriteReadError\x12O\n)COUNTER_PQ_WRITE_TIMESTAMP_OFFSET_IS_LOST\x10\x1f\x1a \x82\xd6\x1b\x1c\n\x1aTimestampWriteOffsetIsLost\x12\x31\n\x16\x43OUNTER_PQ_SID_CREATED\x10 \x1a\x15\x82\xd6\x1b\x11\n\x0fSourceIdCreated\x12\x44\n#COUNTER_PQ_WRITE_BYTES_SMALL_OFFSET\x10!\x1a\x1b\x82\xd6\x1b\x17\n\x15\x42ytesWriteSmallOffset\x12\x39\n\x1d\x43OUNTER_PQ_WRITE_SMALL_OFFSET\x10\"\x1a\x16\x82\xd6\x1b\x12\n\x10WriteSmallOffset\x12/\n\x1b\x43OUNTER_PQ_TABLET_CPU_USAGE\x10#\x1a\x0e\x82\xd6\x1b\n\n\x08\x43PUUsage\x12=\n%COUNTER_PQ_TABLET_NETWORK_BYTES_USAGE\x10$\x1a\x12\x82\xd6\x1b\x0e\n\x0cNetworkUsage*\xc3\x03\n\x0f\x45SimpleCounters\x12<\n\x1c\x43OUNTER_PQ_TABLET_CACHE_SIZE\x10\x00\x1a\x1a\x82\xd6\x1b\x16\n\x14TabletCacheSizeBytes\x12=\n\x1d\x43OUNTER_PQ_TABLET_CACHE_COUNT\x10\x01\x1a\x1a\x82\xd6\x1b\x16\n\x14TabletCacheSizeBlobs\x12>\n COUNTER_PQ_TABLET_CACHED_ON_READ\x10\x02\x1a\x18\x82\xd6\x1b\x14\n\x12TabletCachedOnRead\x12@\n!COUNTER_PQ_TABLET_CACHED_ON_WRATE\x10\x03\x1a\x19\x82\xd6\x1b\x15\n\x13TabletCachedOnWrite\x12\x42\n%COUNTER_PQ_TABLET_RESERVED_BYTES_SIZE\x10\x04\x1a\x17\x82\xd6\x1b\x13\n\x11ReservedBytesSize\x12\x35\n\x1e\x43OUNTER_PQ_TABLET_OPENED_PIPES\x10\x05\x1a\x11\x82\xd6\x1b\r\n\x0bOpenedPipes\x12\x36\n\x1a\x43OUNTER_PQ_TABLET_INFLIGHT\x10\x06\x1a\x16\x82\xd6\x1b\x12\n\x10RequestsInflight*\xd7\r\n\x13\x45PercentileCounters\x12?\n!COUNTER_LATENCY_PQ_GET_MAX_SEQ_NO\x10\x00\x1a\x18\x82\xd6\x1b\x14\n\x12LatencyGetMaxSeqNo\x12\x41\n!COUNTER_LATENCY_PQ_DELETE_SESSION\x10\x01\x1a\x1a\x82\xd6\x1b\x16\n\x14LatencyDeleteSession\x12\x41\n!COUNTER_LATENCY_PQ_CREATE_SESSION\x10\x02\x1a\x1a\x82\xd6\x1b\x16\n\x14LatencyCreateSession\x12\x39\n\x1d\x43OUNTER_LATENCY_PQ_SET_OFFSET\x10\x03\x1a\x16\x82\xd6\x1b\x12\n\x10LatencySetOffset\x12\x39\n\x1d\x43OUNTER_LATENCY_PQ_GET_OFFSET\x10\x04\x1a\x16\x82\xd6\x1b\x12\n\x10LatencyGetOffset\x12\x30\n\x18\x43OUNTER_LATENCY_PQ_WRITE\x10\x05\x1a\x12\x82\xd6\x1b\x0e\n\x0cLatencyWrite\x12.\n\x17\x43OUNTER_LATENCY_PQ_READ\x10\x06\x1a\x11\x82\xd6\x1b\r\n\x0bLatencyRead\x12\x33\n\x1a\x43OUNTER_LATENCY_PQ_READ_OK\x10\x07\x1a\x13\x82\xd6\x1b\x0f\n\rLatencyReadOk\x12\x39\n\x1d\x43OUNTER_LATENCY_PQ_READ_ERROR\x10\x08\x1a\x16\x82\xd6\x1b\x12\n\x10LatencyReadError\x12@\n!COUNTER_LATENCY_PQ_READ_HEAD_ONLY\x10\t\x1a\x19\x82\xd6\x1b\x15\n\x13LatencyReadHeadOnly\x12?\n COUNTER_LATENCY_PQ_GET_OWNERSHIP\x10\n\x1a\x19\x82\xd6\x1b\x15\n\x13LatencyGetOwnership\x12;\n\x1e\x43OUNTER_LATENCY_PQ_WRITE_CYCLE\x10\x0b\x1a\x17\x82\xd6\x1b\x13\n\x11LatencyWriteCycle\x12.\n\x17\x43OUNTER_LATENCY_PQ_INIT\x10\x0c\x1a\x11\x82\xd6\x1b\r\n\x0bLatencyInit\x12\xad\x01\n\x1c\x43OUNTER_PQ_WRITE_CYCLE_BYTES\x10\r\x1a\x8a\x01\x82\xd6\x1b\x85\x01\n\x0fWriteCycleBytes\x12\x08\x08\x00\x12\x04\x30 Kb\x12\x0c\x08\x80\xa0\x06\x12\x06\x31\x30\x30 Kb\x12\x0c\x08\x80\xc0\x0c\x12\x06\x32\x30\x30 Kb\x12\x0c\x08\x80\x80 \x12\x06\x35\x31\x32 Kb\x12\n\x08\x80\x80@\x12\x04\x31 Mb\x12\x0b\x08\x80\x80\x80\x01\x12\x04\x32 Mb\x12\x0b\x08\x80\x80\x80\x02\x12\x04\x34 Mb\x12\x0b\x08\x80\x80\x80\x03\x12\x04\x36 Mb\x12\x0b\x08\x80\x80\x80\x04\x12\x04\x38 Mb\x12\xa9\x01\n\x1a\x43OUNTER_PQ_WRITE_NEW_BYTES\x10\x0e\x1a\x88\x01\x82\xd6\x1b\x83\x01\n\rWriteNewBytes\x12\x08\x08\x00\x12\x04\x30 Kb\x12\x0c\x08\x80\xa0\x06\x12\x06\x31\x30\x30 Kb\x12\x0c\x08\x80\xc0\x0c\x12\x06\x32\x30\x30 Kb\x12\x0c\x08\x80\x80 \x12\x06\x35\x31\x32 Kb\x12\n\x08\x80\x80@\x12\x04\x31 Mb\x12\x0b\x08\x80\x80\x80\x01\x12\x04\x32 Mb\x12\x0b\x08\x80\x80\x80\x02\x12\x04\x34 Mb\x12\x0b\x08\x80\x80\x80\x03\x12\x04\x36 Mb\x12\x0b\x08\x80\x80\x80\x04\x12\x04\x38 Mb\x12>\n COUNTER_LATENCY_PQ_RECEIVE_QUEUE\x10\x0f\x1a\x18\x82\xd6\x1b\x14\n\x12LatencyReciveQueue\x12?\n COUNTER_LATENCY_PQ_RESERVE_BYTES\x10\x10\x1a\x19\x82\xd6\x1b\x15\n\x13LatencyReserveBytes\x12P\n)COUNTER_LATENCY_PQ_REGISTER_MESSAGE_GROUP\x10\x11\x1a!\x82\xd6\x1b\x1d\n\x1bLatencyRegisterMessageGroup\x12T\n+COUNTER_LATENCY_PQ_DEREGISTER_MESSAGE_GROUP\x10\x12\x1a#\x82\xd6\x1b\x1f\n\x1dLatencyDeregisterMessageGroup\x12J\n&COUNTER_LATENCY_PQ_SPLIT_MESSAGE_GROUP\x10\x13\x1a\x1e\x82\xd6\x1b\x1a\n\x18LatencySplitMessageGroup\x1a\xef\x01\x92\xd6\x1b\xea\x01\x12\x08\x08\x00\x12\x04\x30 ms\x12\t\x08\x32\x12\x05\x35\x30 ms\x12\n\x08\x64\x12\x06\x31\x30\x30 ms\x12\x0b\x08\xc8\x01\x12\x06\x32\x30\x30 ms\x12\x0b\x08\xac\x02\x12\x06\x33\x30\x30 ms\x12\x0b\x08\x90\x03\x12\x06\x34\x30\x30 ms\x12\x0b\x08\xf4\x03\x12\x06\x35\x30\x30 ms\x12\x0b\x08\xee\x05\x12\x06\x37\x35\x30 ms\x12\x0c\x08\xe8\x07\x12\x07\x31\x30\x30\x30 ms\x12\x0c\x08\xdc\x0b\x12\x07\x31\x35\x30\x30 ms\x12\x0c\x08\xd0\x0f\x12\x07\x32\x30\x30\x30 ms\x12\x0c\x08\x88\'\x12\x07\x35\x30\x30\x30 ms\x12\r\x08\x90N\x12\x08\x31\x30\x30\x30\x30 ms\x12\x0e\x08\xa0\x9c\x01\x12\x08\x32\x30\x30\x30\x30 ms\x12\x0e\x08\xb0\xea\x01\x12\x08\x33\x30\x30\x30\x30 ms\x12\x0e\x08\xe0\xd4\x03\x12\x08\x36\x30\x30\x30\x30 ms\x12\x0f\x08\xc0\xa9\x07\x12\t120000 ms*\xf0\x10\n\x16\x45\x43lientLabeledCounters\x12v\n\x18METRIC_COMMIT_WRITE_TIME\x10\x00\x1aX\xa2\xd6\x1bT\n\x19WriteTimeLagMsByCommitted\x10\x02\x18\x02\"3topic.partition.committed_read_lag_milliseconds_max\x12~\n\x19METRIC_COMMIT_CREATE_TIME\x10\x01\x1a_\xa2\xd6\x1b[\n\x1a\x43reateTimeLagMsByCommitted\x10\x02\x18\x02\"9topic.partition.committed_end_to_end_lag_milliseconds_max\x12h\n\x19METRIC_COMMIT_MESSAGE_LAG\x10\x02\x1aI\xa2\xd6\x1b\x45\n\x15MessageLagByCommitted\x10\x01\"*topic.partition.committed_lag_messages_max\x12\x38\n\x16METRIC_COMMIT_SIZE_LAG\x10\x03\x1a\x1c\xa2\xd6\x1b\x18\n\x12SizeLagByCommitted\x10\x01\"\x00\x12\x43\n\x16METRIC_READ_WRITE_TIME\x10\x04\x1a\'\xa2\xd6\x1b#\n\x1bWriteTimeLagMsByLastReadOld\x10\x02\x18\x02\"\x00\x12m\n\x16METRIC_READ_TOTAL_TIME\x10\x05\x1aQ\xa2\xd6\x1bM\n\x18TotalTimeLagMsByLastRead\x10\x01\"/topic.partition.end_to_end_lag_milliseconds_max\x12`\n\x17METRIC_READ_MESSAGE_LAG\x10\x06\x1a\x43\xa2\xd6\x1b?\n\x14MessageLagByLastRead\x10\x01\"%topic.partition.read.lag_messages_max\x12\x35\n\x14METRIC_READ_SIZE_LAG\x10\x07\x1a\x1b\xa2\xd6\x1b\x17\n\x11SizeLagByLastRead\x10\x01\"\x00\x12W\n\x16METRIC_USER_PARTITIONS\x10\x08\x1a;\xa2\xd6\x1b\x37\n\x16UserPartitionsAnswered\x10\x03\"\x1btopic.partition.alive_count\x12]\n\x1dMETRIC_READ_TOTAL_MESSAGE_LAG\x10\t\x1a:\xa2\xd6\x1b\x36\n\x19TotalMessageLagByLastRead\x10\x03\"\x17topic.read.lag_messages\x12@\n\x1aMETRIC_READ_TOTAL_SIZE_LAG\x10\n\x1a \xa2\xd6\x1b\x1c\n\x16TotalSizeLagByLastRead\x10\x03\"\x00\x12I\n%METRIC_MIN_READ_QUOTA_BYTES_AVAIL_SEC\x10\x0b\x1a\x1e\xa2\xd6\x1b\x1a\n\x14ReadBytesAvailAvgSec\x10\x02\"\x00\x12I\n%METRIC_MIN_READ_QUOTA_BYTES_AVAIL_MIN\x10\x0c\x1a\x1e\xa2\xd6\x1b\x1a\n\x14ReadBytesAvailAvgMin\x10\x02\"\x00\x12\x42\n\x1dMETRIC_READ_OFFSET_REWIND_SUM\x10\r\x1a\x1f\xa2\xd6\x1b\x1b\n\x13ReadOffsetRewindSum\x10\x03\x18\x03\"\x00\x12\x38\n\x19METRIC_TOTAL_READ_SPEED_1\x10\x0e\x1a\x19\xa2\xd6\x1b\x15\n\x0fReadBytesPerSec\x10\x03\"\x00\x12\x39\n\x17METRIC_MAX_READ_SPEED_1\x10\x0f\x1a\x1c\xa2\xd6\x1b\x18\n\x12ReadBytesMaxPerSec\x10\x01\"\x00\x12\x38\n\x19METRIC_TOTAL_READ_SPEED_2\x10\x10\x1a\x19\xa2\xd6\x1b\x15\n\x0fReadBytesPerMin\x10\x03\"\x00\x12\x39\n\x17METRIC_MAX_READ_SPEED_2\x10\x11\x1a\x1c\xa2\xd6\x1b\x18\n\x12ReadBytesMaxPerMin\x10\x01\"\x00\x12\x39\n\x19METRIC_TOTAL_READ_SPEED_3\x10\x12\x1a\x1a\xa2\xd6\x1b\x16\n\x10ReadBytesPerHour\x10\x03\"\x00\x12:\n\x17METRIC_MAX_READ_SPEED_3\x10\x13\x1a\x1d\xa2\xd6\x1b\x19\n\x13ReadBytesMaxPerHour\x10\x01\"\x00\x12\x38\n\x19METRIC_TOTAL_READ_SPEED_4\x10\x14\x1a\x19\xa2\xd6\x1b\x15\n\x0fReadBytesPerDay\x10\x03\"\x00\x12\x39\n\x17METRIC_MAX_READ_SPEED_4\x10\x15\x1a\x1c\xa2\xd6\x1b\x18\n\x12ReadBytesMaxPerDay\x10\x01\"\x00\x12\x35\n\x17METRIC_READ_QUOTA_BYTES\x10\x16\x1a\x18\xa2\xd6\x1b\x14\n\x0eReadBytesQuota\x10\x02\"\x00\x12Z\n\x14METRIC_READ_TIME_LAG\x10\x17\x1a@\xa2\xd6\x1b<\n\rReadTimeLagMs\x10\x01\")topic.partition.read.lag_milliseconds_max\x12g\n\x15METRIC_WRITE_TIME_LAG\x10\x18\x1aL\xa2\xd6\x1bH\n\x18WriteTimeLagMsByLastRead\x10\x01\"*topic.partition.write.lag_milliseconds_max\x12\x64\n\x15METRIC_LAST_READ_TIME\x10\x19\x1aI\xa2\xd6\x1b\x45\n\x13TimeSinceLastReadMs\x10\x02\x18\x02\"*topic.partition.read.idle_milliseconds_max\x12\x41\n\x17METRIC_READ_QUOTA_USAGE\x10\x1a\x1a$\xa2\xd6\x1b \n\x1aPartitionMaxReadQuotaUsage\x10\x01\"\x00\x1a\x1e\xaa\xd6\x1b\x1a\n\x06\x63lient\n\timportant\n\x05topic*\xcd\x14\n\x19\x45PartitionLabeledCounters\x12\\\n\x10METRIC_LIFE_TIME\x10\x00\x1a\x46\xa2\xd6\x1b\x42\n\x13PartitionLifeTimeMs\x10\x01\x18\x02\"\'topic.partition.uptime_milliseconds_min\x12\x61\n\x10METRIC_INIT_TIME\x10\x01\x1aK\xa2\xd6\x1bG\n\x13PartitionInitTimeMs\x10\x01\".topic.partition.init_duration_milliseconds_max\x12N\n\x11METRIC_PARTITIONS\x10\x02\x1a\x37\xa2\xd6\x1b\x33\n\x12PartitionsAnswered\x10\x03\"\x1btopic.partition.alive_count\x12\x41\n\x0fMETRIC_NUM_SIDS\x10\x03\x1a,\xa2\xd6\x1b(\n\rSourceIdCount\x10\x03\"\x15topic.producers_count\x12V\n\x13METRIC_MAX_NUM_SIDS\x10\x04\x1a=\xa2\xd6\x1b\x39\n\x10SourceIdMaxCount\x10\x01\"#topic.partition.producers_count_max\x12*\n\x11METRIC_GAPS_COUNT\x10\x05\x1a\x13\xa2\xd6\x1b\x0f\n\tGapsCount\x10\x03\"\x00\x12\x31\n\x15METRIC_MAX_GAPS_COUNT\x10\x06\x1a\x16\xa2\xd6\x1b\x12\n\x0cGapsMaxCount\x10\x01\"\x00\x12(\n\x10METRIC_GAPS_SIZE\x10\x07\x1a\x12\xa2\xd6\x1b\x0e\n\x08GapsSize\x10\x03\"\x00\x12/\n\x14METRIC_MAX_GAPS_SIZE\x10\x08\x1a\x15\xa2\xd6\x1b\x11\n\x0bGapsMaxSize\x10\x01\"\x00\x12K\n&METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_SEC\x10\t\x1a\x1f\xa2\xd6\x1b\x1b\n\x15WriteBytesAvailAvgSec\x10\x02\"\x00\x12K\n&METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_MIN\x10\n\x1a\x1f\xa2\xd6\x1b\x1b\n\x15WriteBytesAvailAvgMin\x10\x02\"\x00\x12:\n\x1aMETRIC_TOTAL_WRITE_SPEED_1\x10\x0b\x1a\x1a\xa2\xd6\x1b\x16\n\x10WriteBytesPerSec\x10\x03\"\x00\x12;\n\x18METRIC_MAX_WRITE_SPEED_1\x10\x0c\x1a\x1d\xa2\xd6\x1b\x19\n\x13WriteBytesMaxPerSec\x10\x01\"\x00\x12:\n\x1aMETRIC_TOTAL_WRITE_SPEED_2\x10\r\x1a\x1a\xa2\xd6\x1b\x16\n\x10WriteBytesPerMin\x10\x03\"\x00\x12;\n\x18METRIC_MAX_WRITE_SPEED_2\x10\x0e\x1a\x1d\xa2\xd6\x1b\x19\n\x13WriteBytesMaxPerMin\x10\x01\"\x00\x12;\n\x1aMETRIC_TOTAL_WRITE_SPEED_3\x10\x0f\x1a\x1b\xa2\xd6\x1b\x17\n\x11WriteBytesPerHour\x10\x03\"\x00\x12<\n\x18METRIC_MAX_WRITE_SPEED_3\x10\x10\x1a\x1e\xa2\xd6\x1b\x1a\n\x14WriteBytesMaxPerHour\x10\x01\"\x00\x12:\n\x1aMETRIC_TOTAL_WRITE_SPEED_4\x10\x11\x1a\x1a\xa2\xd6\x1b\x16\n\x10WriteBytesPerDay\x10\x03\"\x00\x12;\n\x18METRIC_MAX_WRITE_SPEED_4\x10\x12\x1a\x1d\xa2\xd6\x1b\x19\n\x13WriteBytesMaxPerDay\x10\x01\"\x00\x12\x46\n\x16METRIC_TOTAL_PART_SIZE\x10\x13\x1a*\xa2\xd6\x1b&\n\rTotalPartSize\x10\x03\"\x13topic.storage_bytes\x12P\n\x14METRIC_MAX_PART_SIZE\x10\x14\x1a\x36\xa2\xd6\x1b\x32\n\x0bMaxPartSize\x10\x01\"!topic.partition.storage_bytes_max\x12i\n\x18METRIC_WRITE_QUOTA_BYTES\x10\x15\x1aK\xa2\xd6\x1bG\n\x0fWriteBytesQuota\x10\x02\"2topic.partition.write.speed_limit_bytes_per_second\x12k\n\x18METRIC_WRITE_TIME_LAG_MS\x10\x16\x1aM\xa2\xd6\x1bI\n\x19WriteTimeLagMsByLastWrite\x10\x01\"*topic.partition.write.lag_milliseconds_max\x12g\n\x16METRIC_LAST_WRITE_TIME\x10\x17\x1aK\xa2\xd6\x1bG\n\x14TimeSinceLastWriteMs\x10\x02\x18\x02\"+topic.partition.write.idle_milliseconds_max\x12:\n\x1aMETRIC_TOTAL_QUOTA_SPEED_1\x10\x18\x1a\x1a\xa2\xd6\x1b\x16\n\x10QuotaBytesPerSec\x10\x03\"\x00\x12;\n\x18METRIC_MAX_QUOTA_SPEED_1\x10\x19\x1a\x1d\xa2\xd6\x1b\x19\n\x13QuotaBytesMaxPerSec\x10\x01\"\x00\x12:\n\x1aMETRIC_TOTAL_QUOTA_SPEED_2\x10\x1a\x1a\x1a\xa2\xd6\x1b\x16\n\x10QuotaBytesPerMin\x10\x03\"\x00\x12\x65\n\x18METRIC_MAX_QUOTA_SPEED_2\x10\x1b\x1aG\xa2\xd6\x1b\x43\n\x13QuotaBytesMaxPerMin\x10\x01\"*topic.partition.write.bytes_per_minute_max\x12;\n\x1aMETRIC_TOTAL_QUOTA_SPEED_3\x10\x1c\x1a\x1b\xa2\xd6\x1b\x17\n\x11QuotaBytesPerHour\x10\x03\"\x00\x12\x64\n\x18METRIC_MAX_QUOTA_SPEED_3\x10\x1d\x1a\x46\xa2\xd6\x1b\x42\n\x14QuotaBytesMaxPerHour\x10\x01\"(topic.partition.write.bytes_per_hour_max\x12:\n\x1aMETRIC_TOTAL_QUOTA_SPEED_4\x10\x1e\x1a\x1a\xa2\xd6\x1b\x16\n\x10QuotaBytesPerDay\x10\x03\"\x00\x12\x62\n\x18METRIC_MAX_QUOTA_SPEED_4\x10\x1f\x1a\x44\xa2\xd6\x1b@\n\x13QuotaBytesMaxPerDay\x10\x01\"\'topic.partition.write.bytes_per_day_max\x12r\n\x18METRIC_WRITE_QUOTA_USAGE\x10 \x1aT\xa2\xd6\x1bP\n\x1bPartitionMaxWriteQuotaUsage\x10\x01\"/topic.partition.write.throttled_nanoseconds_max\x12<\n\x17METRIC_MIN_SID_LIFETIME\x10!\x1a\x1f\xa2\xd6\x1b\x1b\n\x15SourceIdMinLifetimeMs\x10\x02\"\x00\x12Q\n\x17METRIC_PARTITIONS_TOTAL\x10\"\x1a\x34\xa2\xd6\x1b\x30\n\x0fPartitionsTotal\x10\x01\"\x1btopic.partition.total_count\x1a\x0b\xaa\xd6\x1b\x07\n\x05topicB\x1e\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x02PQ')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_pq_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\002PQ'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_BAD_REQUEST"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_BAD_REQUEST"]._serialized_options = b'\202\326\033\014\n\nBadRequest'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_INITIALIZING"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_INITIALIZING"]._serialized_options = b'\202\326\033\016\n\014Initializing'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_CREATE_SESSION_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_CREATE_SESSION_OK"]._serialized_options = b'\202\326\033\021\n\017CreateSessionOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_CREATE_SESSION_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_CREATE_SESSION_ERROR"]._serialized_options = b'\202\326\033\024\n\022CreateSessionError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_DELETE_SESSION_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_DELETE_SESSION_OK"]._serialized_options = b'\202\326\033\021\n\017DeleteSessionOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_DELETE_SESSION_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_DELETE_SESSION_ERROR"]._serialized_options = b'\202\326\033\024\n\022DeleteSessionError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SET_CLIENT_OFFSET_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SET_CLIENT_OFFSET_OK"]._serialized_options = b'\202\326\033\023\n\021SetClientOffsetOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SET_CLIENT_OFFSET_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SET_CLIENT_OFFSET_ERROR"]._serialized_options = b'\202\326\033\026\n\024SetClientOffsetError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_GET_CLIENT_OFFSET_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_GET_CLIENT_OFFSET_OK"]._serialized_options = b'\202\326\033\023\n\021GetClientOffsetOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_GET_CLIENT_OFFSET_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_GET_CLIENT_OFFSET_ERROR"]._serialized_options = b'\202\326\033\026\n\024GetClientOffsetError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_OK"]._serialized_options = b'\202\326\033\010\n\006ReadOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR"]._serialized_options = b'\202\326\033\013\n\tReadError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_NO_SESSION"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_NO_SESSION"]._serialized_options = b'\202\326\033\024\n\022ReadErrorNoSession'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_SMALL_OFFSET"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_SMALL_OFFSET"]._serialized_options = b'\202\326\033\026\n\024ReadErrorSmallOffset'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_BIG_OFFSET"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_BIG_OFFSET"]._serialized_options = b'\202\326\033\024\n\022ReadErrorBigOffset'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_IN_PROGRESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_IN_PROGRESS"]._serialized_options = b'\202\326\033\025\n\023ReadErrorInProgress'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_HEAD_ONLY_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_HEAD_ONLY_OK"]._serialized_options = b'\202\326\033\020\n\016ReadHeadOnlyOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_OK"]._serialized_options = b'\202\326\033\024\n\022ReadSubscriptionOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_ERROR"]._serialized_options = b'\202\326\033\027\n\025ReadSubscriptionError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_TIMEOUT"]._serialized_options = b'\202\326\033\031\n\027ReadSubscriptionTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_BYTES"]._serialized_options = b'\202\326\033\013\n\tBytesRead'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_OK"]._serialized_options = b'\202\326\033\016\n\014BytesWriteOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_ALREADY"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_ALREADY"]._serialized_options = b'\202\326\033\023\n\021BytesWriteAlready'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_ERROR"]._serialized_options = b'\202\326\033\021\n\017BytesWriteError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_OK"]._serialized_options = b'\202\326\033\t\n\007WriteOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_ALREADY"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_ALREADY"]._serialized_options = b'\202\326\033\016\n\014WriteAlready'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_ERROR"]._serialized_options = b'\202\326\033\014\n\nWriteError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_CYCLE_BYTES_TOTAL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_CYCLE_BYTES_TOTAL"]._serialized_options = b'\202\326\033\026\n\024BytesWriteCycleTotal'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_CACHE_HIT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_CACHE_HIT"]._serialized_options = b'\202\326\033\030\n\026TimestampWriteCacheHit'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_CACHE_MISS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_CACHE_MISS"]._serialized_options = b'\202\326\033\031\n\027TimestampWriteCacheMiss'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_ERROR"]._serialized_options = b'\202\326\033\031\n\027TimestampWriteReadError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_OFFSET_IS_LOST"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_OFFSET_IS_LOST"]._serialized_options = b'\202\326\033\034\n\032TimestampWriteOffsetIsLost'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SID_CREATED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SID_CREATED"]._serialized_options = b'\202\326\033\021\n\017SourceIdCreated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_SMALL_OFFSET"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_SMALL_OFFSET"]._serialized_options = b'\202\326\033\027\n\025BytesWriteSmallOffset'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_SMALL_OFFSET"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_SMALL_OFFSET"]._serialized_options = b'\202\326\033\022\n\020WriteSmallOffset'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CPU_USAGE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CPU_USAGE"]._serialized_options = b'\202\326\033\n\n\010CPUUsage'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_TABLET_NETWORK_BYTES_USAGE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_TABLET_NETWORK_BYTES_USAGE"]._serialized_options = b'\202\326\033\016\n\014NetworkUsage'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHE_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHE_SIZE"]._serialized_options = b'\202\326\033\026\n\024TabletCacheSizeBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHE_COUNT"]._serialized_options = b'\202\326\033\026\n\024TabletCacheSizeBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHED_ON_READ"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHED_ON_READ"]._serialized_options = b'\202\326\033\024\n\022TabletCachedOnRead'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHED_ON_WRATE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHED_ON_WRATE"]._serialized_options = b'\202\326\033\025\n\023TabletCachedOnWrite'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_RESERVED_BYTES_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_RESERVED_BYTES_SIZE"]._serialized_options = b'\202\326\033\023\n\021ReservedBytesSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_OPENED_PIPES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_OPENED_PIPES"]._serialized_options = b'\202\326\033\r\n\013OpenedPipes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_INFLIGHT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_INFLIGHT"]._serialized_options = b'\202\326\033\022\n\020RequestsInflight'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\352\001\022\010\010\000\022\0040 ms\022\t\0102\022\00550 ms\022\n\010d\022\006100 ms\022\013\010\310\001\022\006200 ms\022\013\010\254\002\022\006300 ms\022\013\010\220\003\022\006400 ms\022\013\010\364\003\022\006500 ms\022\013\010\356\005\022\006750 ms\022\014\010\350\007\022\0071000 ms\022\014\010\334\013\022\0071500 ms\022\014\010\320\017\022\0072000 ms\022\014\010\210\'\022\0075000 ms\022\r\010\220N\022\01010000 ms\022\016\010\240\234\001\022\01020000 ms\022\016\010\260\352\001\022\01030000 ms\022\016\010\340\324\003\022\01060000 ms\022\017\010\300\251\007\022\t120000 ms'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_MAX_SEQ_NO"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_MAX_SEQ_NO"]._serialized_options = b'\202\326\033\024\n\022LatencyGetMaxSeqNo'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_DELETE_SESSION"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_DELETE_SESSION"]._serialized_options = b'\202\326\033\026\n\024LatencyDeleteSession'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_CREATE_SESSION"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_CREATE_SESSION"]._serialized_options = b'\202\326\033\026\n\024LatencyCreateSession'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_SET_OFFSET"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_SET_OFFSET"]._serialized_options = b'\202\326\033\022\n\020LatencySetOffset'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_OFFSET"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_OFFSET"]._serialized_options = b'\202\326\033\022\n\020LatencyGetOffset'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_WRITE"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_WRITE"]._serialized_options = b'\202\326\033\016\n\014LatencyWrite'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ"]._serialized_options = b'\202\326\033\r\n\013LatencyRead'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_OK"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_OK"]._serialized_options = b'\202\326\033\017\n\rLatencyReadOk'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_ERROR"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_ERROR"]._serialized_options = b'\202\326\033\022\n\020LatencyReadError'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_HEAD_ONLY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_HEAD_ONLY"]._serialized_options = b'\202\326\033\025\n\023LatencyReadHeadOnly'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_OWNERSHIP"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_OWNERSHIP"]._serialized_options = b'\202\326\033\025\n\023LatencyGetOwnership'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_WRITE_CYCLE"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_WRITE_CYCLE"]._serialized_options = b'\202\326\033\023\n\021LatencyWriteCycle'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_INIT"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_INIT"]._serialized_options = b'\202\326\033\r\n\013LatencyInit'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PQ_WRITE_CYCLE_BYTES"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PQ_WRITE_CYCLE_BYTES"]._serialized_options = b'\202\326\033\205\001\n\017WriteCycleBytes\022\010\010\000\022\0040 Kb\022\014\010\200\240\006\022\006100 Kb\022\014\010\200\300\014\022\006200 Kb\022\014\010\200\200 \022\006512 Kb\022\n\010\200\200@\022\0041 Mb\022\013\010\200\200\200\001\022\0042 Mb\022\013\010\200\200\200\002\022\0044 Mb\022\013\010\200\200\200\003\022\0046 Mb\022\013\010\200\200\200\004\022\0048 Mb'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PQ_WRITE_NEW_BYTES"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PQ_WRITE_NEW_BYTES"]._serialized_options = b'\202\326\033\203\001\n\rWriteNewBytes\022\010\010\000\022\0040 Kb\022\014\010\200\240\006\022\006100 Kb\022\014\010\200\300\014\022\006200 Kb\022\014\010\200\200 \022\006512 Kb\022\n\010\200\200@\022\0041 Mb\022\013\010\200\200\200\001\022\0042 Mb\022\013\010\200\200\200\002\022\0044 Mb\022\013\010\200\200\200\003\022\0046 Mb\022\013\010\200\200\200\004\022\0048 Mb'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_RECEIVE_QUEUE"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_RECEIVE_QUEUE"]._serialized_options = b'\202\326\033\024\n\022LatencyReciveQueue'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_RESERVE_BYTES"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_RESERVE_BYTES"]._serialized_options = b'\202\326\033\025\n\023LatencyReserveBytes'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_REGISTER_MESSAGE_GROUP"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_REGISTER_MESSAGE_GROUP"]._serialized_options = b'\202\326\033\035\n\033LatencyRegisterMessageGroup'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_DEREGISTER_MESSAGE_GROUP"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_DEREGISTER_MESSAGE_GROUP"]._serialized_options = b'\202\326\033\037\n\035LatencyDeregisterMessageGroup'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_SPLIT_MESSAGE_GROUP"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_SPLIT_MESSAGE_GROUP"]._serialized_options = b'\202\326\033\032\n\030LatencySplitMessageGroup'
  _ECLIENTLABELEDCOUNTERS._options = None
  _ECLIENTLABELEDCOUNTERS._serialized_options = b'\252\326\033\032\n\006client\n\timportant\n\005topic'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_WRITE_TIME"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_WRITE_TIME"]._serialized_options = b'\242\326\033T\n\031WriteTimeLagMsByCommitted\020\002\030\002\"3topic.partition.committed_read_lag_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_CREATE_TIME"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_CREATE_TIME"]._serialized_options = b'\242\326\033[\n\032CreateTimeLagMsByCommitted\020\002\030\002\"9topic.partition.committed_end_to_end_lag_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_MESSAGE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_MESSAGE_LAG"]._serialized_options = b'\242\326\033E\n\025MessageLagByCommitted\020\001\"*topic.partition.committed_lag_messages_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_SIZE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_SIZE_LAG"]._serialized_options = b'\242\326\033\030\n\022SizeLagByCommitted\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_WRITE_TIME"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_WRITE_TIME"]._serialized_options = b'\242\326\033#\n\033WriteTimeLagMsByLastReadOld\020\002\030\002\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_TIME"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_TIME"]._serialized_options = b'\242\326\033M\n\030TotalTimeLagMsByLastRead\020\001\"/topic.partition.end_to_end_lag_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_MESSAGE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_MESSAGE_LAG"]._serialized_options = b'\242\326\033?\n\024MessageLagByLastRead\020\001\"%topic.partition.read.lag_messages_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_SIZE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_SIZE_LAG"]._serialized_options = b'\242\326\033\027\n\021SizeLagByLastRead\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_USER_PARTITIONS"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_USER_PARTITIONS"]._serialized_options = b'\242\326\0337\n\026UserPartitionsAnswered\020\003\"\033topic.partition.alive_count'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_MESSAGE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_MESSAGE_LAG"]._serialized_options = b'\242\326\0336\n\031TotalMessageLagByLastRead\020\003\"\027topic.read.lag_messages'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_SIZE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_SIZE_LAG"]._serialized_options = b'\242\326\033\034\n\026TotalSizeLagByLastRead\020\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MIN_READ_QUOTA_BYTES_AVAIL_SEC"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MIN_READ_QUOTA_BYTES_AVAIL_SEC"]._serialized_options = b'\242\326\033\032\n\024ReadBytesAvailAvgSec\020\002\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MIN_READ_QUOTA_BYTES_AVAIL_MIN"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MIN_READ_QUOTA_BYTES_AVAIL_MIN"]._serialized_options = b'\242\326\033\032\n\024ReadBytesAvailAvgMin\020\002\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_OFFSET_REWIND_SUM"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_OFFSET_REWIND_SUM"]._serialized_options = b'\242\326\033\033\n\023ReadOffsetRewindSum\020\003\030\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_1"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_1"]._serialized_options = b'\242\326\033\025\n\017ReadBytesPerSec\020\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_1"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_1"]._serialized_options = b'\242\326\033\030\n\022ReadBytesMaxPerSec\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_2"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_2"]._serialized_options = b'\242\326\033\025\n\017ReadBytesPerMin\020\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_2"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_2"]._serialized_options = b'\242\326\033\030\n\022ReadBytesMaxPerMin\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_3"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_3"]._serialized_options = b'\242\326\033\026\n\020ReadBytesPerHour\020\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_3"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_3"]._serialized_options = b'\242\326\033\031\n\023ReadBytesMaxPerHour\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_4"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_4"]._serialized_options = b'\242\326\033\025\n\017ReadBytesPerDay\020\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_4"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_4"]._serialized_options = b'\242\326\033\030\n\022ReadBytesMaxPerDay\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_QUOTA_BYTES"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_QUOTA_BYTES"]._serialized_options = b'\242\326\033\024\n\016ReadBytesQuota\020\002\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TIME_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TIME_LAG"]._serialized_options = b'\242\326\033<\n\rReadTimeLagMs\020\001\")topic.partition.read.lag_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_WRITE_TIME_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_WRITE_TIME_LAG"]._serialized_options = b'\242\326\033H\n\030WriteTimeLagMsByLastRead\020\001\"*topic.partition.write.lag_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_LAST_READ_TIME"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_LAST_READ_TIME"]._serialized_options = b'\242\326\033E\n\023TimeSinceLastReadMs\020\002\030\002\"*topic.partition.read.idle_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_QUOTA_USAGE"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_QUOTA_USAGE"]._serialized_options = b'\242\326\033 \n\032PartitionMaxReadQuotaUsage\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS._options = None
  _EPARTITIONLABELEDCOUNTERS._serialized_options = b'\252\326\033\007\n\005topic'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_LIFE_TIME"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_LIFE_TIME"]._serialized_options = b'\242\326\033B\n\023PartitionLifeTimeMs\020\001\030\002\"\'topic.partition.uptime_milliseconds_min'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_INIT_TIME"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_INIT_TIME"]._serialized_options = b'\242\326\033G\n\023PartitionInitTimeMs\020\001\".topic.partition.init_duration_milliseconds_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_PARTITIONS"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_PARTITIONS"]._serialized_options = b'\242\326\0333\n\022PartitionsAnswered\020\003\"\033topic.partition.alive_count'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_NUM_SIDS"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_NUM_SIDS"]._serialized_options = b'\242\326\033(\n\rSourceIdCount\020\003\"\025topic.producers_count'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_NUM_SIDS"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_NUM_SIDS"]._serialized_options = b'\242\326\0339\n\020SourceIdMaxCount\020\001\"#topic.partition.producers_count_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_GAPS_COUNT"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_GAPS_COUNT"]._serialized_options = b'\242\326\033\017\n\tGapsCount\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_GAPS_COUNT"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_GAPS_COUNT"]._serialized_options = b'\242\326\033\022\n\014GapsMaxCount\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_GAPS_SIZE"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_GAPS_SIZE"]._serialized_options = b'\242\326\033\016\n\010GapsSize\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_GAPS_SIZE"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_GAPS_SIZE"]._serialized_options = b'\242\326\033\021\n\013GapsMaxSize\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_SEC"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_SEC"]._serialized_options = b'\242\326\033\033\n\025WriteBytesAvailAvgSec\020\002\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_MIN"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_MIN"]._serialized_options = b'\242\326\033\033\n\025WriteBytesAvailAvgMin\020\002\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_1"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_1"]._serialized_options = b'\242\326\033\026\n\020WriteBytesPerSec\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_1"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_1"]._serialized_options = b'\242\326\033\031\n\023WriteBytesMaxPerSec\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_2"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_2"]._serialized_options = b'\242\326\033\026\n\020WriteBytesPerMin\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_2"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_2"]._serialized_options = b'\242\326\033\031\n\023WriteBytesMaxPerMin\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_3"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_3"]._serialized_options = b'\242\326\033\027\n\021WriteBytesPerHour\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_3"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_3"]._serialized_options = b'\242\326\033\032\n\024WriteBytesMaxPerHour\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_4"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_4"]._serialized_options = b'\242\326\033\026\n\020WriteBytesPerDay\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_4"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_4"]._serialized_options = b'\242\326\033\031\n\023WriteBytesMaxPerDay\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_PART_SIZE"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_PART_SIZE"]._serialized_options = b'\242\326\033&\n\rTotalPartSize\020\003\"\023topic.storage_bytes'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_PART_SIZE"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_PART_SIZE"]._serialized_options = b'\242\326\0332\n\013MaxPartSize\020\001\"!topic.partition.storage_bytes_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_QUOTA_BYTES"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_QUOTA_BYTES"]._serialized_options = b'\242\326\033G\n\017WriteBytesQuota\020\002\"2topic.partition.write.speed_limit_bytes_per_second'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_TIME_LAG_MS"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_TIME_LAG_MS"]._serialized_options = b'\242\326\033I\n\031WriteTimeLagMsByLastWrite\020\001\"*topic.partition.write.lag_milliseconds_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_LAST_WRITE_TIME"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_LAST_WRITE_TIME"]._serialized_options = b'\242\326\033G\n\024TimeSinceLastWriteMs\020\002\030\002\"+topic.partition.write.idle_milliseconds_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_1"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_1"]._serialized_options = b'\242\326\033\026\n\020QuotaBytesPerSec\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_1"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_1"]._serialized_options = b'\242\326\033\031\n\023QuotaBytesMaxPerSec\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_2"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_2"]._serialized_options = b'\242\326\033\026\n\020QuotaBytesPerMin\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_2"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_2"]._serialized_options = b'\242\326\033C\n\023QuotaBytesMaxPerMin\020\001\"*topic.partition.write.bytes_per_minute_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_3"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_3"]._serialized_options = b'\242\326\033\027\n\021QuotaBytesPerHour\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_3"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_3"]._serialized_options = b'\242\326\033B\n\024QuotaBytesMaxPerHour\020\001\"(topic.partition.write.bytes_per_hour_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_4"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_4"]._serialized_options = b'\242\326\033\026\n\020QuotaBytesPerDay\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_4"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_4"]._serialized_options = b'\242\326\033@\n\023QuotaBytesMaxPerDay\020\001\"\'topic.partition.write.bytes_per_day_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_QUOTA_USAGE"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_QUOTA_USAGE"]._serialized_options = b'\242\326\033P\n\033PartitionMaxWriteQuotaUsage\020\001\"/topic.partition.write.throttled_nanoseconds_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_SID_LIFETIME"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_SID_LIFETIME"]._serialized_options = b'\242\326\033\033\n\025SourceIdMinLifetimeMs\020\002\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_PARTITIONS_TOTAL"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_PARTITIONS_TOTAL"]._serialized_options = b'\242\326\0330\n\017PartitionsTotal\020\001\"\033topic.partition.total_count'
  _ECUMULATIVECOUNTERS._serialized_start=83
  _ECUMULATIVECOUNTERS._serialized_end=2309
  _ESIMPLECOUNTERS._serialized_start=2312
  _ESIMPLECOUNTERS._serialized_end=2763
  _EPERCENTILECOUNTERS._serialized_start=2766
  _EPERCENTILECOUNTERS._serialized_end=4517
  _ECLIENTLABELEDCOUNTERS._serialized_start=4520
  _ECLIENTLABELEDCOUNTERS._serialized_end=6680
  _EPARTITIONLABELEDCOUNTERS._serialized_start=6683
  _EPARTITIONLABELEDCOUNTERS._serialized_end=9320
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_vdisk_internal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import blobstorage_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__pb2
from ydb.core.protos import blobstorage_disk_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ydb/core/protos/blobstorage_vdisk_internal.proto\x12\x10NKikimrVDiskData\x1a\x1aydb/core/protos/base.proto\x1a!ydb/core/protos/blobstorage.proto\x1a&ydb/core/protos/blobstorage_disk.proto\";\n\tTDiskPart\x12\x10\n\x08\x43hunkIdx\x18\x01 \x01(\r\x12\x0e\n\x06Offset\x18\x02 \x01(\r\x12\x0c\n\x04Size\x18\x03 \x01(\r\">\n\x0cTDiskPartVec\x12.\n\tDiskParts\x18\x01 \x03(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart\"A\n\x11TPhantomLogoBlobs\x12,\n\tLogoBlobs\x18\x01 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"\xa3\x01\n\x12TBulkFormedSstInfo\x12\x14\n\x0c\x46irstBlobLsn\x18\x01 \x01(\x04\x12\x13\n\x0bLastBlobLsn\x18\x02 \x01(\x04\x12/\n\nEntryPoint\x18\x03 \x01(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart\x12\x10\n\x08\x43hunkIds\x18\x04 \x03(\r\x12\x1f\n\x10RemovedFromIndex\x18\x05 \x01(\x08:\x05\x66\x61lse\"O\n\x15TBulkFormedSstInfoSet\x12\x36\n\x08Segments\x18\x01 \x03(\x0b\x32$.NKikimrVDiskData.TBulkFormedSstInfo\"4\n\x07TLevel0\x12)\n\x04Ssts\x18\x01 \x03(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart\"K\n\x07TLevelX\x12)\n\x04Ssts\x18\x01 \x03(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart\x12\x15\n\rLastCompacted\x18\x02 \x01(\x0c\"\xef\x01\n\x0bTLevelIndex\x12)\n\x06Level0\x18\x01 \x01(\x0b\x32\x19.NKikimrVDiskData.TLevel0\x12.\n\x0bOtherLevels\x18\x02 \x03(\x0b\x32\x19.NKikimrVDiskData.TLevelX\x12\x15\n\rDeletedChunks\x18\x03 \x03(\r\x12\x45\n\x14\x42ulkFormedSstInfoSet\x18\x04 \x01(\x0b\x32\'.NKikimrVDiskData.TBulkFormedSstInfoSet\x12\x11\n\tNextSstId\x18\x0b \x01(\x04\x12\x14\n\x0c\x43ompactedLsn\x18\x0c \x01(\x04\"\xd2\x02\n\x11THullDbEntryPoint\x12\x31\n\nLevelIndex\x18\x01 \x01(\x0b\x32\x1d.NKikimrVDiskData.TLevelIndex\x12\x38\n\x10RemovedHugeBlobs\x18\x02 \x01(\x0b\x32\x1e.NKikimrVDiskData.TDiskPartVec\x12\x64\n\x1bUncommittedRemovedHugeBlobs\x18\x03 \x03(\x0b\x32?.NKikimrVDiskData.THullDbEntryPoint.TUncommittedRemovedHugeBlob\x1aj\n\x1bTUncommittedRemovedHugeBlob\x12\x11\n\tRecordLsn\x18\x01 \x01(\x04\x12\x38\n\x10RemovedHugeBlobs\x18\x02 \x01(\x0b\x32\x1e.NKikimrVDiskData.TDiskPartVec\"\x8a\x04\n\x11TSyncerVDiskEntry\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x37\n\x0cSyncGuidInfo\x18\x05 \x01(\x0b\x32!.NKikimrBlobStorage.TSyncGuidInfo\x12G\n\x0eLastSyncStatus\x18\x0b \x01(\x0e\x32/.NKikimrVDiskData.TSyncerVDiskEntry.ESyncStatus\x12\x31\n\tSyncState\x18\x0c \x01(\x0b\x32\x1e.NKikimrBlobStorage.TSyncState\x12\x0f\n\x07SchTime\x18\r \x01(\x04\x12\x0f\n\x07LastTry\x18\x0e \x01(\x04\x12\x10\n\x08LastGood\x18\x0f \x01(\x04\"\xdc\x01\n\x0b\x45SyncStatus\x12\x0b\n\x07Running\x10\x00\x12\x11\n\rProtocolError\x10\x01\x12\x08\n\x04Race\x10\x02\x12\t\n\x05\x45rror\x10\x03\x12\x0f\n\x0b\x46ullRecover\x10\x04\x12\x0f\n\x0b\x44isksSynced\x10\x05\x12\x0c\n\x08NotReady\x10\x06\x12\n\n\x06Locked\x10\x07\x12\x0c\n\x08SyncDone\x10\x08\x12\x0b\n\x07Timeout\x10\t\x12\r\n\tRedirLoop\x10\n\x12\x0b\n\x07Unknown\x10\x0b\x12\x15\n\x11\x44roppedConnection\x10\x0c\x12\x0e\n\nOutOfSpace\x10\r\"\x84\x01\n\x11TSyncerEntryPoint\x12\x39\n\rLocalGuidInfo\x18\x05 \x01(\x0b\x32\".NKikimrBlobStorage.TLocalGuidInfo\x12\x34\n\x07\x45ntries\x18\n \x03(\x0b\x32#.NKikimrVDiskData.TSyncerVDiskEntry\"\x9e\x02\n\x0fTIncrHugeChunks\x12<\n\x06\x43hunks\x18\x01 \x03(\x0b\x32,.NKikimrVDiskData.TIncrHugeChunks.TChunkInfo\x12\x15\n\rDeletedChunks\x18\x02 \x03(\r\x12\x15\n\rCurrentSerNum\x18\x03 \x01(\x04\x1aq\n\nTChunkInfo\x12\x10\n\x08\x43hunkIdx\x18\x01 \x01(\r\x12\x13\n\x0b\x43hunkSerNum\x18\x02 \x01(\x04\x12<\n\x05State\x18\x03 \x01(\x0e\x32-.NKikimrVDiskData.TIncrHugeChunks.EChunkState\",\n\x0b\x45\x43hunkState\x12\x0c\n\x08\x43omplete\x10\x01\x12\x0f\n\x0bWriteIntent\x10\x02\"\x85\x04\n\x0fTIncrHugeDelete\x12<\n\x06\x43hunks\x18\x01 \x03(\x0b\x32,.NKikimrVDiskData.TIncrHugeDelete.TChunkInfo\x12<\n\x06Owners\x18\x02 \x03(\x0b\x32,.NKikimrVDiskData.TIncrHugeDelete.TOwnerInfo\x1a\xc9\x02\n\nTChunkInfo\x12\x13\n\x0b\x43hunkSerNum\x18\x01 \x01(\x04\x12R\n\x0c\x44\x65letedItems\x18\x02 \x01(\x0b\x32:.NKikimrVDiskData.TIncrHugeDelete.TChunkInfo.TDeletedItemsH\x00\x12\x0e\n\x04\x42its\x18\x03 \x01(\x0cH\x00\x1a*\n\nTItemRange\x12\r\n\x05\x46irst\x18\x01 \x01(\r\x12\r\n\x05\x43ount\x18\x02 \x01(\r\x1ai\n\rTDeletedItems\x12\x0f\n\x07Indexes\x18\x01 \x03(\r\x12G\n\x06Ranges\x18\x02 \x03(\x0b\x32\x37.NKikimrVDiskData.TIncrHugeDelete.TChunkInfo.TItemRange\x1a\x1c\n\x0cTDeletedBits\x12\x0c\n\x04\x42its\x18\x01 \x01(\x0c\x42\r\n\x0b\x44\x65letedData\x1a*\n\nTOwnerInfo\x12\r\n\x05Owner\x18\x01 \x01(\r\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\"O\n\x1eTAnubisOsirisPutRecoveryLogRec\x12-\n\nLogoBlobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"\xec\x02\n\x19TAddBulkSstRecoveryLogRec\x12V\n\x12LogoBlobsAdditions\x18\x01 \x03(\x0b\x32:.NKikimrVDiskData.TAddBulkSstRecoveryLogRec.TSstAndRecsNum\x12S\n\x0f\x42locksAdditions\x18\x02 \x03(\x0b\x32:.NKikimrVDiskData.TAddBulkSstRecoveryLogRec.TSstAndRecsNum\x12U\n\x11\x42\x61rriersAdditions\x18\x03 \x03(\x0b\x32:.NKikimrVDiskData.TAddBulkSstRecoveryLogRec.TSstAndRecsNum\x1aK\n\x0eTSstAndRecsNum\x12(\n\x03Sst\x18\x01 \x01(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart\x12\x0f\n\x07RecsNum\x18\x02 \x01(\r\"\xe7\x01\n\x12TSyncLogEntryPoint\x12\x11\n\tPDiskGuid\x18\x01 \x01(\x06\x12\x1c\n\x14VDiskIncarnationGuid\x18\x02 \x01(\x06\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x13\n\x0bLogStartLsn\x18\n \x01(\x04\x12\x1f\n\x17RecoveryLogConfirmedLsn\x18\x0b \x01(\x04\x12\x1d\n\x15\x43hunksToDeleteDelayed\x18\x14 \x03(\r\x12\x1c\n\x14\x44iskRecLogSerialized\x18\x15 \x01(\x0c\"|\n\x0bTScrubState\x12\x18\n\x10NextSstIdToScrub\x18\x01 \x01(\x04\x12)\n\x06\x42lobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x0f\n\x07Success\x18\x03 \x01(\x08\x12\x17\n\x0fIncarnationGuid\x18\x04 \x01(\x06\"\xa8\x02\n\x10TScrubEntrypoint\x12P\n\x0fUnreadableBlobs\x18\x01 \x03(\x0b\x32\x37.NKikimrVDiskData.TScrubEntrypoint.TUnreadableBlobState\x12\x31\n\nScrubState\x18\x02 \x01(\x0b\x32\x1d.NKikimrVDiskData.TScrubState\x1a\x8e\x01\n\x14TUnreadableBlobState\x12)\n\x06\x42lobId\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x17\n\x0fUnreadableParts\x18\x02 \x01(\r\x12\x32\n\rCorruptedPart\x18\x03 \x01(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_vdisk_internal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TDISKPART._serialized_start=173
  _TDISKPART._serialized_end=232
  _TDISKPARTVEC._serialized_start=234
  _TDISKPARTVEC._serialized_end=296
  _TPHANTOMLOGOBLOBS._serialized_start=298
  _TPHANTOMLOGOBLOBS._serialized_end=363
  _TBULKFORMEDSSTINFO._serialized_start=366
  _TBULKFORMEDSSTINFO._serialized_end=529
  _TBULKFORMEDSSTINFOSET._serialized_start=531
  _TBULKFORMEDSSTINFOSET._serialized_end=610
  _TLEVEL0._serialized_start=612
  _TLEVEL0._serialized_end=664
  _TLEVELX._serialized_start=666
  _TLEVELX._serialized_end=741
  _TLEVELINDEX._serialized_start=744
  _TLEVELINDEX._serialized_end=983
  _THULLDBENTRYPOINT._serialized_start=986
  _THULLDBENTRYPOINT._serialized_end=1324
  _THULLDBENTRYPOINT_TUNCOMMITTEDREMOVEDHUGEBLOB._serialized_start=1218
  _THULLDBENTRYPOINT_TUNCOMMITTEDREMOVEDHUGEBLOB._serialized_end=1324
  _TSYNCERVDISKENTRY._serialized_start=1327
  _TSYNCERVDISKENTRY._serialized_end=1849
  _TSYNCERVDISKENTRY_ESYNCSTATUS._serialized_start=1629
  _TSYNCERVDISKENTRY_ESYNCSTATUS._serialized_end=1849
  _TSYNCERENTRYPOINT._serialized_start=1852
  _TSYNCERENTRYPOINT._serialized_end=1984
  _TINCRHUGECHUNKS._serialized_start=1987
  _TINCRHUGECHUNKS._serialized_end=2273
  _TINCRHUGECHUNKS_TCHUNKINFO._serialized_start=2114
  _TINCRHUGECHUNKS_TCHUNKINFO._serialized_end=2227
  _TINCRHUGECHUNKS_ECHUNKSTATE._serialized_start=2229
  _TINCRHUGECHUNKS_ECHUNKSTATE._serialized_end=2273
  _TINCRHUGEDELETE._serialized_start=2276
  _TINCRHUGEDELETE._serialized_end=2793
  _TINCRHUGEDELETE_TCHUNKINFO._serialized_start=2420
  _TINCRHUGEDELETE_TCHUNKINFO._serialized_end=2749
  _TINCRHUGEDELETE_TCHUNKINFO_TITEMRANGE._serialized_start=2555
  _TINCRHUGEDELETE_TCHUNKINFO_TITEMRANGE._serialized_end=2597
  _TINCRHUGEDELETE_TCHUNKINFO_TDELETEDITEMS._serialized_start=2599
  _TINCRHUGEDELETE_TCHUNKINFO_TDELETEDITEMS._serialized_end=2704
  _TINCRHUGEDELETE_TCHUNKINFO_TDELETEDBITS._serialized_start=2706
  _TINCRHUGEDELETE_TCHUNKINFO_TDELETEDBITS._serialized_end=2734
  _TINCRHUGEDELETE_TOWNERINFO._serialized_start=2751
  _TINCRHUGEDELETE_TOWNERINFO._serialized_end=2793
  _TANUBISOSIRISPUTRECOVERYLOGREC._serialized_start=2795
  _TANUBISOSIRISPUTRECOVERYLOGREC._serialized_end=2874
  _TADDBULKSSTRECOVERYLOGREC._serialized_start=2877
  _TADDBULKSSTRECOVERYLOGREC._serialized_end=3241
  _TADDBULKSSTRECOVERYLOGREC_TSSTANDRECSNUM._serialized_start=3166
  _TADDBULKSSTRECOVERYLOGREC_TSSTANDRECSNUM._serialized_end=3241
  _TSYNCLOGENTRYPOINT._serialized_start=3244
  _TSYNCLOGENTRYPOINT._serialized_end=3475
  _TSCRUBSTATE._serialized_start=3477
  _TSCRUBSTATE._serialized_end=3601
  _TSCRUBENTRYPOINT._serialized_start=3604
  _TSCRUBENTRYPOINT._serialized_end=3900
  _TSCRUBENTRYPOINT_TUNREADABLEBLOBSTATE._serialized_start=3758
  _TSCRUBENTRYPOINT_TUNREADABLEBLOBSTATE._serialized_end=3900
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/actors/protos/dq_events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.library.yql.dq.actors.protos import dq_stats_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__stats__pb2
from ydb.library.yql.dq.actors.protos import dq_status_codes_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__status__codes__pb2
from ydb.library.yql.dq.proto import dq_state_load_plan_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__state__load__plan__pb2
from ydb.library.yql.dq.proto import dq_tasks_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__tasks__pb2
from ydb.library.yql.dq.proto import dq_transport_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__transport__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ydb/library/yql/dq/actors/protos/dq_events.proto\x12\rNYql.NDqProto\x1a&library/cpp/actors/protos/actors.proto\x1a/ydb/library/yql/dq/actors/protos/dq_stats.proto\x1a\x36ydb/library/yql/dq/actors/protos/dq_status_codes.proto\x1a\x31ydb/library/yql/dq/proto/dq_state_load_plan.proto\x1a\'ydb/library/yql/dq/proto/dq_tasks.proto\x1a+ydb/library/yql/dq/proto/dq_transport.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\"-\n\x0bTCheckpoint\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\"!\n\nTWatermark\x12\x13\n\x0bTimestampUs\x18\x01 \x01(\x04\"\xb5\x01\n\x0cTChannelData\x12\x11\n\tChannelId\x18\x01 \x01(\x04\x12\"\n\x04\x44\x61ta\x18\x02 \x01(\x0b\x32\x14.NYql.NDqProto.TData\x12\x10\n\x08\x46inished\x18\x03 \x01(\x08\x12.\n\nCheckpoint\x18\x04 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12,\n\tWatermark\x18\x05 \x01(\x0b\x32\x19.NYql.NDqProto.TWatermark\"E\n\x06TEvRun\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\":\n\x0fTEvChannelsInfo\x12\'\n\x06Update\x18\x01 \x03(\x0b\x32\x17.NYql.NDqProto.TChannel\"C\n\x12TComputeActorStats\x12\'\n\x07\x41\x63torId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorIdJ\x04\x08\x02\x10\x03\"\xb5\x02\n\x14TEvComputeActorState\x12\r\n\x05State\x18\x01 \x01(\r\x12\x36\n\x0bLegacyStats\x18\x02 \x01(\x0b\x32!.NYql.NDqProto.TComputeActorStats\x12\x30\n\rYdbStatusCode\x18\x03 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x04 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x0e\n\x06TaskId\x18\x05 \x01(\x04\x12\x32\n\x05Stats\x18\x06 \x01(\x0b\x32#.NYql.NDqProto.TDqComputeActorStats\x12\x37\n\nStatusCode\x18\x07 \x01(\x0e\x32#.NYql.NDqProto.StatusIds.StatusCode\"\x18\n\x16TEvComputeStateRequest\"y\n\x15TEvComputeChannelData\x12\x30\n\x0b\x43hannelData\x18\x01 \x01(\x0b\x32\x1b.NYql.NDqProto.TChannelData\x12\x10\n\x08SendTime\x18\x02 \x01(\x04\x12\r\n\x05SeqNo\x18\x03 \x01(\x04\x12\r\n\x05NoAck\x18\x04 \x01(\x08\"_\n\x18TEvComputeChannelDataAck\x12\x11\n\tChannelId\x18\x01 \x01(\x04\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\x12\x11\n\tFreeSpace\x18\x03 \x01(\x03\x12\x0e\n\x06\x46inish\x18\x04 \x01(\x08\"\xbe\x01\n\x11TEvAbortExecution\x12\x30\n\rYdbStatusCode\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\x15\n\rLegacyMessage\x18\x02 \x01(\t\x12\x37\n\nStatusCode\x18\x03 \x01(\x0e\x32#.NYql.NDqProto.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x04 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"Z\n\x07TRlPath\x12\x18\n\x10\x43oordinationNode\x18\x01 \x01(\t\x12\x14\n\x0cResourcePath\x18\x02 \x01(\t\x12\x10\n\x08\x44\x61tabase\x18\x03 \x01(\t\x12\r\n\x05Token\x18\x04 \x01(\t\"\xc0\x02\n\x17TComputeRuntimeSettings\x12\x11\n\tTimeoutMs\x18\x01 \x01(\r\x12\x42\n\x08\x45xecType\x18\x02 \x01(\x0e\x32\x30.NYql.NDqProto.TComputeRuntimeSettings.EExecType\x12.\n\tStatsMode\x18\x08 \x01(\x0e\x32\x1b.NYql.NDqProto.EDqStatsMode\x12\x0f\n\x07UseLLVM\x18\x04 \x01(\x08\x12\x13\n\x0bUseSpilling\x18\x06 \x01(\x08\x12\x18\n\x10TasksOnNodeCount\x18\x05 \x01(\r\x12&\n\x06RlPath\x18\x07 \x01(\x0b\x32\x16.NYql.NDqProto.TRlPath\"0\n\tEExecType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04SCAN\x10\x01\x12\x08\n\x04\x44\x41TA\x10\x02J\x04\x08\x03\x10\x04\"\x7f\n\x1bTEvNewCheckpointCoordinator\x12\x12\n\nGeneration\x18\x01 \x01(\x04\x12\x0f\n\x07GraphId\x18\x02 \x01(\t\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"]\n\x1eTEvNewCheckpointCoordinatorAck\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\x96\x01\n\x13TEvInjectCheckpoint\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\xca\x02\n\x16TEvSaveTaskStateResult\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x0e\n\x06TaskId\x18\x02 \x01(\x04\x12=\n\x06Status\x18\x03 \x01(\x0e\x32-.NYql.NDqProto.TEvSaveTaskStateResult.EStatus\x12\x16\n\x0eStateSizeBytes\x18\x04 \x01(\x04\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\\\n\x07\x45Status\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x11\n\rSTORAGE_ERROR\x10\x02\x12\x12\n\x0eINTERNAL_ERROR\x10\x03\x12\x11\n\rSTATE_TOO_BIG\x10\x04\"\x91\x01\n\x0eTEvCommitState\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\x90\x01\n\x11TEvStateCommitted\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x0e\n\x06TaskId\x18\x02 \x01(\x04\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\xdd\x01\n\x18TEvRestoreFromCheckpoint\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12@\n\rStateLoadPlan\x18\x03 \x01(\x0b\x32).NYql.NDqProto.NDqStateLoadPlan.TTaskPlan\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\xbd\x02\n\x1eTEvRestoreFromCheckpointResult\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x0e\n\x06TaskId\x18\x02 \x01(\x04\x12L\n\x06Status\x18\x03 \x01(\x0e\x32<.NYql.NDqProto.TEvRestoreFromCheckpointResult.ERestoreStatus\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"P\n\x0e\x45RestoreStatus\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x11\n\rSTORAGE_ERROR\x10\x02\x12\x12\n\x0eINTERNAL_ERROR\x10\x03\">\n\x15TMessageTransportMeta\x12\r\n\x05SeqNo\x18\x01 \x01(\x04\x12\x16\n\x0e\x43onfirmedSeqNo\x18\x02 \x01(\x04*~\n\rEComputeState\x12\x19\n\x15\x43OMPUTE_STATE_UNKNOWN\x10\x00\x12\x19\n\x15\x43OMPUTE_STATE_FAILURE\x10\x01\x12\x1b\n\x17\x43OMPUTE_STATE_EXECUTING\x10\x02\x12\x1a\n\x16\x43OMPUTE_STATE_FINISHED\x10\x03\x42\x03\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.actors.protos.dq_events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _ECOMPUTESTATE._serialized_start=3687
  _ECOMPUTESTATE._serialized_end=3813
  _TCHECKPOINT._serialized_start=442
  _TCHECKPOINT._serialized_end=487
  _TWATERMARK._serialized_start=489
  _TWATERMARK._serialized_end=522
  _TCHANNELDATA._serialized_start=525
  _TCHANNELDATA._serialized_end=706
  _TEVRUN._serialized_start=708
  _TEVRUN._serialized_end=777
  _TEVCHANNELSINFO._serialized_start=779
  _TEVCHANNELSINFO._serialized_end=837
  _TCOMPUTEACTORSTATS._serialized_start=839
  _TCOMPUTEACTORSTATS._serialized_end=906
  _TEVCOMPUTEACTORSTATE._serialized_start=909
  _TEVCOMPUTEACTORSTATE._serialized_end=1218
  _TEVCOMPUTESTATEREQUEST._serialized_start=1220
  _TEVCOMPUTESTATEREQUEST._serialized_end=1244
  _TEVCOMPUTECHANNELDATA._serialized_start=1246
  _TEVCOMPUTECHANNELDATA._serialized_end=1367
  _TEVCOMPUTECHANNELDATAACK._serialized_start=1369
  _TEVCOMPUTECHANNELDATAACK._serialized_end=1464
  _TEVABORTEXECUTION._serialized_start=1467
  _TEVABORTEXECUTION._serialized_end=1657
  _TRLPATH._serialized_start=1659
  _TRLPATH._serialized_end=1749
  _TCOMPUTERUNTIMESETTINGS._serialized_start=1752
  _TCOMPUTERUNTIMESETTINGS._serialized_end=2072
  _TCOMPUTERUNTIMESETTINGS_EEXECTYPE._serialized_start=2018
  _TCOMPUTERUNTIMESETTINGS_EEXECTYPE._serialized_end=2066
  _TEVNEWCHECKPOINTCOORDINATOR._serialized_start=2074
  _TEVNEWCHECKPOINTCOORDINATOR._serialized_end=2201
  _TEVNEWCHECKPOINTCOORDINATORACK._serialized_start=2203
  _TEVNEWCHECKPOINTCOORDINATORACK._serialized_end=2296
  _TEVINJECTCHECKPOINT._serialized_start=2299
  _TEVINJECTCHECKPOINT._serialized_end=2449
  _TEVSAVETASKSTATERESULT._serialized_start=2452
  _TEVSAVETASKSTATERESULT._serialized_end=2782
  _TEVSAVETASKSTATERESULT_ESTATUS._serialized_start=2690
  _TEVSAVETASKSTATERESULT_ESTATUS._serialized_end=2782
  _TEVCOMMITSTATE._serialized_start=2785
  _TEVCOMMITSTATE._serialized_end=2930
  _TEVSTATECOMMITTED._serialized_start=2933
  _TEVSTATECOMMITTED._serialized_end=3077
  _TEVRESTOREFROMCHECKPOINT._serialized_start=3080
  _TEVRESTOREFROMCHECKPOINT._serialized_end=3301
  _TEVRESTOREFROMCHECKPOINTRESULT._serialized_start=3304
  _TEVRESTOREFROMCHECKPOINTRESULT._serialized_end=3621
  _TEVRESTOREFROMCHECKPOINTRESULT_ERESTORESTATUS._serialized_start=3541
  _TEVRESTOREFROMCHECKPOINTRESULT_ERESTORESTATUS._serialized_end=3621
  _TMESSAGETRANSPORTMETA._serialized_start=3623
  _TMESSAGETRANSPORTMETA._serialized_end=3685
# @@protoc_insertion_point(module_scope)



import sys
import copy
import os
import shutil
import textwrap
import itertools


def halt(*args):
    print(*args, file=sys.stderr)
    sys.exit(1)


def internal_error(*args):
    halt('INTERNAL ERROR:', *args)


def get_parser(element):
    if isinstance(element, ArgumentParser):
        return element
    elif isinstance(element, (Parser, Subparsers, ArgumentMetaInfo, ValueMetaInfo)):
        if element.parser is None:
            raise ValueError(f'Element with type {type(element).__name__} with None parser')
        return element.parser
    elif isinstance(element, Argument):
        return get_parser(element.metainfo)
    elif isinstance(element, ValueHolder):
        return get_parser(element.metainfo)
    elif isinstance(element, MutuallyExclusiveGroup):
        return get_parser(element._parser)
    raise TypeError(f'Unknown argument type for get_parser, got {type(element)}')
    internal_error()


def print_with_word_wrapping(msg='', initial_indent='', subsequent_indent='', file=sys.stdout):
    width, _ = shutil.get_terminal_size()
    if width <= len(initial_indent):
        raise ValueError(f'initial_indent ({len(initial_indent)}) more than width ({width}) in terminal')
    if width <= len(subsequent_indent):
        raise ValueError(f'subsequent_indent ({len(subsequent_indent)}) more than width ({width}) in terminal')
    if isinstance(msg, str):
        lines = msg.splitlines()
    else:
        lines = list(itertools.chain((line.splitlines() for line in msg)))
    for line in lines:
        if line:
            text = textwrap.fill(
                line,
                width=width,
                initial_indent=initial_indent,
                subsequent_indent=subsequent_indent,
                drop_whitespace=False,
                replace_whitespace=False)
            print(text, file=file)
        else:
            print(initial_indent)
        initial_indent = subsequent_indent


def print_error_with_usage(element, msg):
    parser = get_parser(element)
    usage = parser._generate_usage()
    print_with_word_wrapping(usage, file=sys.stderr)
    print_with_word_wrapping(msg, file=sys.stderr)
    print_with_word_wrapping(f"To see more info run '{parser.generate_help_command()}'")
    sys.exit(1)


class ValueMetaInfo:
    def __init__(self, name, type, choices, parser):
        self.name = name
        self.type = type
        self.choices = choices
        self.owners = []
        self.parser = parser

    def apply_value(self, value):
        error_msg = None
        if self.choices is not None and value is not None and value not in self.choices:
            error_msg = 'Unexpected value {0} for {1}, it should be one of the next values: {2}'.format(
                value, self.name, ', '.join(self.choices))
        if self.type is not None:
            try:
                value = self.type(value)
            except Exception:
                error_msg = 'Can\'t convert value {0} to type {1} for {2}'.format(
                    value, self.type, self.name)
        if error_msg is not None:
            print_error_with_usage(self, error_msg)
        return value

    def add_owner(self, owner):
        self.owners.append(owner)

    def _additional_eq(self, other):
        return True

    def __eq__(self, other):
        return all((
            type(self) == type(other),
            self.name == other.name,
            self.type == other.type,
            self.choices == other.choices,
            self._additional_eq(other)
        ))


class SingleValueMetaInfo(ValueMetaInfo):
    def __init__(self, name, type, choices, default, required, parser=None):
        ValueMetaInfo.__init__(self, name, type, choices, parser)
        self.default = default
        self.required = required

    def _additional_eq(self, other):
        return self.default == other.default and self.required == other.required


class ListValueMetaInfo(ValueMetaInfo):
    def __init__(self, name, type, choices, required, min_count, max_count, parser=None):
        ValueMetaInfo.__init__(self, name, type, choices, parser)
        self.default = None
        self.min_count = min_count
        self.max_count = max_count
        self.required = required

    def _additional_eq(self, other):
        return self.min_count == other.min_count and self.max_count == other.max_count


class ValueHolder:
    def __init__(self, metainfo):
        self.metainfo = metainfo
        self._value = None
        self._referencing_args = []
        self.clear()

    def clear(self):
        self._value = copy.copy(self.metainfo.default)

    def value(self):
        return self._value

    def set_field(self, args):
        setattr(args, self.metainfo.name, self._value)

    def apply_value(self, arg):
        internal_error('Used method in base class without implementation')

    def check(self, arg):
        internal_error('Used method in base class without implementation')


class SingleValueHolder(ValueHolder):
    def __init__(self, metainfo):
        if not isinstance(metainfo, SingleValueMetaInfo):
            internal_error('Uncorrect metainfo for class SingleValueHolder')
        ValueHolder.__init__(self, metainfo)
        self._has_value = False

    def clear(self):
        ValueHolder.clear(self)
        self._has_value = False

    def apply_value(self, value):
        if self._has_value:
            print_error_with_usage(self, 'Value {0} already assigned by {1}, unexpected new value {2}'.format(
                self.metainfo.name, self._value, value))
        self._value = self.metainfo.apply_value(value)
        self._has_value = True

    def check(self):
        if self.metainfo.required and not self._has_value:
            print_error_with_usage(self, 'Value {0} is required'.format(self.metainfo.name))


class ListValueHolder(ValueHolder):
    def __init__(self, metainfo):
        if not isinstance(metainfo, ListValueMetaInfo):
            internal_error('Uncorrect metainfo for class ListValueHolder')
        ValueHolder.__init__(self, metainfo)
        self._has_value = False

    def clear(self):
        ValueHolder.clear(self)

    def apply_value(self, value):
        if self._value is None:
            self._value = list()
        applyed_values = len(self._value)
        if self.metainfo.max_count is not None and applyed_values >= self.metainfo.max_count:
            print_error_with_usage(self, 'Value {0} already riched max item count'.format(self.metainfo.name))
        self._value.append(self.metainfo.apply_value(value))
        self._has_value = True

    def check(self):
        if self.metainfo.required and not self._has_value:
            print_error_with_usage(self, 'Value {0} is required'.format(self.metainfo.name))
        if self._value is not None and len(self._value) < self.metainfo.min_count and self._has_value:
            print_error_with_usage(self, 'Value {0} is expected minimum {1} items, but gotten only {2}'.format(
                self.metainfo.name, self.metainfo.min_count, len(self._value)))


class ArgumentMetaInfo:
    def __init__(self, name, aliases, help, description=None, metavar=None, multivalue=False, is_expecting_value=True, parser=None):
        self.name = name
        self.aliases = aliases
        self.help = help
        self.description = description
        self.metavar = metavar
        self.multivalue = multivalue
        self.is_expecting_value = is_expecting_value
        self.parser = parser
        if parser is None:
            raise ValueError("parser mustn't be None")

    def make_lines_for_help(self, with_metavar):
        if len(self.aliases) > 1:
            res = '{{{0}}}'.format('|'.join(self.aliases))
        else:
            res = self.aliases[0]
        if self.metavar:
            res += ' ' + self.metavar
        elif with_metavar:
            res += ' ' + self.name.upper().replace('-', '_')
        return (res, self.help)


class Argument:
    def __init__(self, metainfo: ArgumentMetaInfo, value: ValueHolder, action):
        self.metainfo = metainfo
        self._value = value
        self._action = action
        self._is_presented = False
        if self._value is not None:
            self._value.metainfo.add_owner(self)

    def clear(self):
        if self._value is not None:
            self._value.clear()
        self._is_presented = False

    def apply(self, *args):
        self._action(self, *args)
        self._is_presented = True

    def is_expecting_value(self):
        return self.metainfo.is_expecting_value

    def make_help_lines(self):
        return self.metainfo.make_lines_for_help(self.metainfo.is_expecting_value)

    def check(self):
        if self._value is not None:
            self._value.check()


class ArgumentActions:
    @staticmethod
    def print_help(arg: Argument):
        arg.metainfo.parser._print_help()
        sys.exit(0)

    @staticmethod
    def make_store_const(const, expected_args=False):
        def set_const(arg: Argument, *args):
            if len(args) == 0:
                arg._value.apply_value(const)
            elif len(args) == 1 and expected_args:
                arg._value.apply_value(args[0])
            else:
                internal_error('Unexpected arguments')
        return set_const

    @staticmethod
    def default_action(arg, value):
        arg._value.apply_value(value)


class Subparsers:
    def __init__(self, value, parser):
        self._value = value
        self.parser = parser
        self._subparsers = []
        self._subparsers_names = []
        self._value.metainfo.choices = self._subparsers_names
        self._subparser_dict = dict()
        if self._value is not None:
            self._value.metainfo.add_owner(self)

    def add_parser(self, command, aliases=None, help=None, description=None):
        if aliases is None:
            aliases = [command]
        else:
            aliases = list(aliases)
            aliases.append(command)
        res = ArgumentParser(prog=command, description=description, help=help, aliases=aliases, parent=self.parser)
        self._subparsers.append(res)
        for alias in aliases:
            self._subparser_dict[alias] = res
            self._subparsers_names.append(alias)
        return res

    def check(self):
        self._value.check()

    def __getitem__(self, name):
        if name not in self._subparser_dict:
            print_error_with_usage(f"Unexpected command '{name}'")
        return self._subparser_dict[name]


class MutuallyExclusiveGroup:
    def __init__(self, group, parser, required=False):
        self._options = []
        self._is_required = required
        self._group = group
        self._parser = parser

    def add_argument(self, name, *args, **kwargs):
        self._options.append(name)
        self._group.add_argument(name, *args, **kwargs)

    def _get_option(self, name):
        return self._group._get_option(name)

    def check(self):
        presented = []
        for opt_name in self._options:
            opt = self._get_option(opt_name)
            if opt._is_presented:
                presented.append(opt_name)
        if self._is_required and not presented:
            print_error_with_usage(self, 'Expected one of the next options: ' + ','.join(self._options))
        if len(presented) > 1:
            print_error_with_usage(self, 'Presented mutually exclusive options: ' + ','.join(presented))

    def option_count(self):
        return len(self._options)


class OptionGroup:
    def __init__(self, title: str, description: str, parser):
        self._title = title
        self.description = description
        self.parser = parser
        self._options = []
        self._mutually_exclusive_groups = []

    def add_argument(self, name, *args, **kwargs):
        self._options.append(name)
        self.parser._add_argument(name, *args, **kwargs)

    def _get_option(self, name):
        return self.parser._option_dict[name]

    def add_mutually_exclusive_group(self, required=False):
        self._mutually_exclusive_groups.append(MutuallyExclusiveGroup(required=required, group=self, parser=self.parser))
        return self._mutually_exclusive_groups[-1]

    def check(self):
        for opt_name in self._options:
            self._get_option(opt_name).check()
        for group in self._mutually_exclusive_groups:
            group.check()

    def option_count(self):
        count = len(self._options)
        for group in self._mutually_exclusive_groups:
            count += group.option_count()
        return count

    def generate_lines_for_help(self):
        lines = [self._title + ':']
        if self._options:
            opt_lines = map(Argument.make_help_lines, map(self._get_option, self._options))
            for opt, help in opt_lines:
                lines.append((opt, '', help))
        return lines

    def generate_short_version_for_help(self):
        names = []
        if self._options:
            opt_lines = map(Argument.make_help_lines, map(self._get_option, self._options))
            for opt, _ in opt_lines:
                names.append(opt)
        return ', '.join(names)


class ArgumentParser:
    def __init__(self, prog=None, description=None, parent=None, aliases=None, help=None):
        self._parent = parent
        self.metainfo = ArgumentMetaInfo(
            sys.argv[0] if prog is None else prog,
            aliases,
            help=help,
            description=description,
            parser=self)
        self._values = dict()
        self._option_groups = []
        self._option_dict = dict()
        self._free_arguments = []
        self._subparsers = None
        self.add_argument_group(title='Options')
        self.add_argument('--help', '-?', '-h', action='print_help', help='Print usage')
        self._terminal_size = None

    def get_terminal_size(self):
        if self._parent is not None:
            return self._parent.get_terminal_size()
        if self._terminal_size is not None:
            return self._terminal_size
        return os.terminal_size(80, 24)

    def _has_additional_options(self):
        count = 0
        for group in self._option_groups:
            count += group.option_count()
        return count > 1

    def _get_options_name(self):
        if self._parent is None:
            return 'global options'
        return self.metainfo.name + ' options'

    def _generate_call_example(self):
        example = self.metainfo.name
        if self._parent:
            example = self._parent._generate_call_example() + ' ' + example
        return example

    def _generate_usage(self, with_subparser=True, with_options=True):
        usage = self.metainfo.name
        if self._parent:
            usage = self._parent._generate_usage(with_subparser=False, with_options=with_options) + ' ' + usage
        if self._has_additional_options() and with_options:
            usage += ' [{0} ...]'.format(self._get_options_name())
        if self._subparsers and with_subparser:
            usage += ' <subcommand>' if self._parent else ' <global_command>'
        return usage

    def generate_help_command(self):
        return f'{self._generate_usage(with_subparser=False, with_options=False)} --help'

    def _generate_description(self):
        return self.metainfo.description if self.metainfo.description else ''

    def _generate_help_text(self):
        return self.metainfo.help if self.metainfo.help else ''

    def _generate_subcommands(self):
        descr = self._generate_help_text()
        lines = [(self.metainfo.name, '', descr)]
        if self._subparsers is None or not self._subparsers._subparsers:
            return lines
        for idx, parser in enumerate(self._subparsers._subparsers):
            is_last = (idx + 1 == len(self._subparsers._subparsers))
            subcommands_lines = parser._generate_subcommands()
            prefixes = ['└─ ', '   '] if is_last else ['├─ ', '│  ']
            for line_idx, line_tuple in enumerate(subcommands_lines):
                prefix_idx = 1 if line_idx else 0
                initial = prefixes[prefix_idx] + line_tuple[0]
                subsequent = prefixes[1] + line_tuple[1]
                lines.append((initial, subsequent, line_tuple[2]))
        return lines

    def _generate_short_options(self):
        lines = []
        if self._parent is not None:
            lines = self._parent._generate_short_options()
        if self._has_additional_options():
            lines.append('')
            name = self._get_options_name()
            lines.append(name[:1].upper() + name[1:] + ':')
            from_groups = []
            for group in self._option_groups:
                from_groups.append(group.generate_short_version_for_help())
            lines.append('  ' + ', '.join(from_groups))
            lines.append("To get full description of these options run '{0} --help'".format(
                self._generate_call_example()))
        return lines

    def _generate_options(self):
        lines = []
        for idx, group in enumerate(self._option_groups):
            lines += group.generate_lines_for_help()
            lines.append('')
        return lines

    def _print_help(self):
        # USAGE
        print_with_word_wrapping('Usage: ' + self._generate_usage())
        # DESCRIPTION
        desc = self._generate_description()
        if desc:
            print()
            print_with_word_wrapping(self._generate_description())

        # SUBCOMMANDS
        subcommands_lines = self._generate_subcommands()
        max_length = 20
        if self._subparsers is not None and self._subparsers._subparsers:
            print()
            print_with_word_wrapping('Subcommands:')
            cmds = (x[0] for x in subcommands_lines)
            max_length = max(max_length, max(map(len, cmds)))
            for command, subsequent, help in subcommands_lines:
                if help:
                    optional_empty_line = '' if len(command) < max_length else '\n'
                    print_with_word_wrapping(
                        f'{optional_empty_line}{help}',
                        initial_indent=f'{command:<{max_length}}',
                        subsequent_indent=f'{subsequent:<{max_length}}')
                else:
                    print_with_word_wrapping(command)
        # SHORT OPTIONS
        if self._parent is not None:
            print()
            short_options_lines = self._parent._generate_short_options()
            if short_options_lines:
                for line in short_options_lines:
                    print_with_word_wrapping(
                        line, subsequent_indent=f'{"":<{4}}')
        # OPTIONS
        options_lines = self._generate_options()
        if options_lines:
            print()
            opts = (x[0] for x in options_lines if isinstance(x, tuple))
            max_length = min(max_length, max(10, max(map(len, opts)) + 2)) - 2
            for line in options_lines:
                if isinstance(line, str):
                    print_with_word_wrapping(line)
                else:
                    opt, empty, help = line
                    optional_empty_line = '' if len(opt) < max_length else '\n'
                    print_with_word_wrapping(
                        f'{optional_empty_line}{help}',
                        initial_indent=f'  {opt:<{max_length-2}}',
                        subsequent_indent=f'{empty:<{max_length}}')
        # FREE ARGS
        free_args_count = len(self._free_arguments) + int(bool(self._subparsers))
        if free_args_count:
            min_args = str(free_args_count)
            max_args = free_args_count if not self._subparsers else 'unlimited'
            print()
            print_with_word_wrapping('Free args: min: {0} max: {1}'.format(min_args, max_args))
            # ! TODO(FREEARGS)
            if self._subparsers:
                line = '  <subcommand>  {0}'.format(', '.join((x.metainfo.name for x in self._subparsers._subparsers)))
                print_with_word_wrapping(line, subsequent_indent='  ')

    def get_option(self, opt_name):
        if opt_name not in self._option_dict:
            print_error_with_usage(self, f'Unknown options {opt_name}')
        return self._option_dict[opt_name]

    def _add_argument(self, name, *aliases, type=None, action=None, default=None, metavar=None, required=False, help='', choices=None, nargs=None, const=None, dest=None):
        realname = name
        if realname.startswith('--'):
            realname = realname[2:]
        if realname.startswith('-'):
            realname = realname[1:]

        if dest is None:
            dest = realname.replace('-', '_')

        multivalue = nargs is not None

        is_expecting_value = True
        if action == 'append' or (nargs is not None and nargs != '?'):
            min_count = 0
            max_count = None
            if nargs == '+':
                min_count = 1
            if isinstance(nargs, int):
                min_count = max_count = nargs
            valuemetainfo = ListValueMetaInfo(dest, type, choices, required, min_count, max_count, parser=self)
        elif action == 'print_help':
            valuemetainfo = None
            is_expecting_value = False
        else:
            if action == 'store_true':
                default = False
            if action == 'store_false':
                default = True
            valuemetainfo = SingleValueMetaInfo(dest, type, choices, default, required, parser=self)
            is_expecting_value = action not in ['store_const', 'store_true', 'store_false']

        value = None
        if valuemetainfo is not None:
            if dest in self._values:
                if valuemetainfo != self._values[dest].metainfo:
                    internal_error('Destination {0} was described twice with different parameters'.format(dest))
                value = self._values[dest]
            else:
                if isinstance(valuemetainfo, SingleValueMetaInfo):
                    value = SingleValueHolder(valuemetainfo)
                else:
                    value = ListValueHolder(valuemetainfo)
                self._values[dest] = value

        arg_action = ArgumentActions.default_action
        if action == 'store_const':
            arg_action = ArgumentActions.make_store_const(const)
        elif action == 'store_true':
            arg_action = ArgumentActions.make_store_const(True)
        elif action == 'store_false':
            arg_action = ArgumentActions.make_store_const(False)
        elif action == 'print_help':
            arg_action = ArgumentActions.print_help
        elif nargs == '?':
            arg_action = ArgumentActions.make_store_const(const, expected_args=True)

        if choices is not None and metavar is None:
            metavar = '{{{0}}}'.format(','.join(map(str, choices)))

        all_aliases = list(aliases)
        all_aliases.append(name)
        metainfo = ArgumentMetaInfo(
            realname, all_aliases, help, metavar=metavar,
            multivalue=multivalue, is_expecting_value=is_expecting_value, parser=self
        )

        arg = Argument(metainfo, value, arg_action)
        if value is not None:
            value._referencing_args.append(arg)

        if name.startswith('-'):
            self._option_dict[name] = arg
            for alias in aliases:
                self._option_dict[alias] = arg
        else:
            self._free_arguments.append(arg)

    def add_argument(self, name, *args, **kvargs):
        if name.startswith('-'):
            self._option_groups[0].add_argument(name, *args, **kvargs)
        else:
            self._add_argument(name, *args, **kvargs)

    def add_argument_group(self, title=None, description=None):
        if title is None:
            title = 'Options'
        if description is None:
            description = ''
        self._option_groups.append(OptionGroup(title, description, self))
        return self._option_groups[-1]

    def add_mutually_exclusive_group(self, *args, **kvargs):
        return self._option_groups[0].add_mutually_exclusive_group(*args, **kvargs)

    def add_subparsers(self, help=None, dest=None, required=False):
        if dest not in self._values:
            metainfo = SingleValueMetaInfo(dest, default=None, type=str, choices=None, required=required, parser=self)
            value = SingleValueHolder(metainfo)
            self._values[dest] = value
        else:
            value = self._values[dest]
        if self._subparsers is None:
            self._subparsers = Subparsers(value, self)
        return self._subparsers

    def parse_args(self, args=None):
        if args is None:
            args = sys.argv[1:]
        real_parser = Parser(args, self)
        real_parser.parse()
        return real_parser.parsed_args


class ParsedArgs:
    def __init__(self):
        pass


class Parser:
    def __init__(self, args, parser, parsed_args=None):
        self.parser = parser
        self._args = args
        self._current_idx = 0
        self._current_parser = parser
        self.parsed_args = parsed_args
        self._free_arg_idx = 0
        self._free_args_limit = len(self.parser._free_arguments) + int(bool(self.parser._subparsers))

    def _shift(self):
        self._current_idx += 1
        if self._current_idx >= len(self._args):
            return False
        return True

    def _value(self):
        return self._args[self._current_idx]

    def _is_end(self):
        return self._current_idx >= len(self._args)

    def _end(self):
        self._current_idx = len(self._args)

    def _apply_value(self, arg):
        arg.apply(self._value())
        self._shift()

    def _apply_multivalue(self, arg):
        while not self._is_end() and not self._value().startswith('-'):
            self._apply_value(arg)

    def _apply_option(self, option):
        if option[0:2] != '--':
            internal_error('Start parsing option without lead \'--\'')
        words = option.split('=')
        value = None
        if len(words) == 1:
            opt_name = words[0]
        elif len(words) == 2:
            [opt_name, value] = words
        else:
            opt_name = words[0]
            value = '='.join(words[1:])
        arg = self.parser.get_option(opt_name)
        if not arg.is_expecting_value() and value is not None:
            print_error_with_usage(self, f'Unexpected value {value} for option {opt_name}')
        if value is not None:
            arg.apply(value)
            self._shift()
        elif not self._shift() or not arg.is_expecting_value():
            arg.apply()
        elif arg.metainfo.multivalue:
            self._apply_multivalue(arg)
        else:
            self._apply_value(arg)

    def _apply_short_options(self, options):
        if options[0] != '-':
            internal_error('Start parsing short options without lead \'-\'')
        options = options[1:]
        for local_idx, opt_char in enumerate(options):
            opt_name = '-' + opt_char
            arg = self.parser.get_option(opt_name)
            if arg.is_expecting_value() and local_idx + 1 < len(options):
                arg.apply(options[local_idx+1:])
                self._shift()
                break
            elif not arg.is_expecting_value():
                arg.apply()
                self._shift()
            elif not self._shift():
                arg.apply()
            elif arg.metainfo.multivalue:
                self._apply_multivalue(arg)
            else:
                self._apply_value(arg)

    def _apply_free_argument(self, value):
        if self._free_arg_idx >= self._free_args_limit:
            print_error_with_usage(self, f'Unexpected free arg {value}')
        if self._free_arg_idx < len(self.parser._free_arguments):
            self.parser._free_arguments[self._free_arg_idx].apply_value(value)
            self._shift()
        else:
            self.parser._subparsers._value.apply_value(value)
            subparser = self.parser._subparsers[value]
            Parser(self._args[self._current_idx+1:], subparser, parsed_args=self.parsed_args).parse()
            self._end()
        self._free_arg_idx += 1

    def parse(self):
        if self.parsed_args is None:
            self.parsed_args = ParsedArgs()
        while not self._is_end():
            value = self._value()
            if value.startswith('--'):
                self._apply_option(value)
            elif value.startswith('-'):
                self._apply_short_options(value)
            else:
                self._apply_free_argument(value)
        for value in self.parser._values.values():
            value.set_field(self.parsed_args)
        for group in self.parser._option_groups:
            group.check()
        if self.parser._subparsers:
            self.parser._subparsers.check()
